// This file was generated by qtwaylandscanner
// source file is /usr/share/plasma-wayland-protocols/contrast.xml

#include "qwayland-contrast.h"

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")

namespace QtWayland {

static inline void *wlRegistryBind(struct ::wl_registry *registry, uint32_t name, const struct ::wl_interface *interface, uint32_t version)
{
    const uint32_t bindOpCode = 0;
#if (WAYLAND_VERSION_MAJOR == 1 && WAYLAND_VERSION_MINOR > 10) || WAYLAND_VERSION_MAJOR > 1
    return (void *) wl_proxy_marshal_constructor_versioned((struct wl_proxy *) registry,
        bindOpCode, interface, version, name, interface->name, version, nullptr);
#else
    return (void *) wl_proxy_marshal_constructor((struct wl_proxy *) registry,
        bindOpCode, interface, name, interface->name, version, nullptr);
#endif
}

    org_kde_kwin_contrast_manager::org_kde_kwin_contrast_manager(struct ::wl_registry *registry, int id, int version)
    {
        init(registry, id, version);
    }

    org_kde_kwin_contrast_manager::org_kde_kwin_contrast_manager(struct ::org_kde_kwin_contrast_manager *obj)
        : m_org_kde_kwin_contrast_manager(obj)
    {
    }

    org_kde_kwin_contrast_manager::org_kde_kwin_contrast_manager()
        : m_org_kde_kwin_contrast_manager(nullptr)
    {
    }

    org_kde_kwin_contrast_manager::~org_kde_kwin_contrast_manager()
    {
    }

    void org_kde_kwin_contrast_manager::init(struct ::wl_registry *registry, int id, int version)
    {
        m_org_kde_kwin_contrast_manager = static_cast<struct ::org_kde_kwin_contrast_manager *>(wlRegistryBind(registry, id, &org_kde_kwin_contrast_manager_interface, version));
    }

    void org_kde_kwin_contrast_manager::init(struct ::org_kde_kwin_contrast_manager *obj)
    {
        m_org_kde_kwin_contrast_manager = obj;
    }

    org_kde_kwin_contrast_manager *org_kde_kwin_contrast_manager::fromObject(struct ::org_kde_kwin_contrast_manager *object)
    {
        return static_cast<org_kde_kwin_contrast_manager *>(org_kde_kwin_contrast_manager_get_user_data(object));
    }

    bool org_kde_kwin_contrast_manager::isInitialized() const
    {
        return m_org_kde_kwin_contrast_manager != nullptr;
    }

    const struct wl_interface *org_kde_kwin_contrast_manager::interface()
    {
        return &::org_kde_kwin_contrast_manager_interface;
    }

    struct ::org_kde_kwin_contrast *org_kde_kwin_contrast_manager::create(struct ::wl_surface *surface)
    {
        return org_kde_kwin_contrast_manager_create(
            m_org_kde_kwin_contrast_manager,
            surface);
    }

    void org_kde_kwin_contrast_manager::unset(struct ::wl_surface *surface)
    {
        org_kde_kwin_contrast_manager_unset(
            m_org_kde_kwin_contrast_manager,
            surface);
    }

    org_kde_kwin_contrast::org_kde_kwin_contrast(struct ::wl_registry *registry, int id, int version)
    {
        init(registry, id, version);
    }

    org_kde_kwin_contrast::org_kde_kwin_contrast(struct ::org_kde_kwin_contrast *obj)
        : m_org_kde_kwin_contrast(obj)
    {
    }

    org_kde_kwin_contrast::org_kde_kwin_contrast()
        : m_org_kde_kwin_contrast(nullptr)
    {
    }

    org_kde_kwin_contrast::~org_kde_kwin_contrast()
    {
    }

    void org_kde_kwin_contrast::init(struct ::wl_registry *registry, int id, int version)
    {
        m_org_kde_kwin_contrast = static_cast<struct ::org_kde_kwin_contrast *>(wlRegistryBind(registry, id, &org_kde_kwin_contrast_interface, version));
    }

    void org_kde_kwin_contrast::init(struct ::org_kde_kwin_contrast *obj)
    {
        m_org_kde_kwin_contrast = obj;
    }

    org_kde_kwin_contrast *org_kde_kwin_contrast::fromObject(struct ::org_kde_kwin_contrast *object)
    {
        return static_cast<org_kde_kwin_contrast *>(org_kde_kwin_contrast_get_user_data(object));
    }

    bool org_kde_kwin_contrast::isInitialized() const
    {
        return m_org_kde_kwin_contrast != nullptr;
    }

    const struct wl_interface *org_kde_kwin_contrast::interface()
    {
        return &::org_kde_kwin_contrast_interface;
    }

    void org_kde_kwin_contrast::commit()
    {
        org_kde_kwin_contrast_commit(
            m_org_kde_kwin_contrast);
    }

    void org_kde_kwin_contrast::set_region(struct ::wl_region *region)
    {
        org_kde_kwin_contrast_set_region(
            m_org_kde_kwin_contrast,
            region);
    }

    void org_kde_kwin_contrast::set_contrast(wl_fixed_t contrast)
    {
        org_kde_kwin_contrast_set_contrast(
            m_org_kde_kwin_contrast,
            contrast);
    }

    void org_kde_kwin_contrast::set_intensity(wl_fixed_t intensity)
    {
        org_kde_kwin_contrast_set_intensity(
            m_org_kde_kwin_contrast,
            intensity);
    }

    void org_kde_kwin_contrast::set_saturation(wl_fixed_t saturation)
    {
        org_kde_kwin_contrast_set_saturation(
            m_org_kde_kwin_contrast,
            saturation);
    }

    void org_kde_kwin_contrast::release()
    {
        org_kde_kwin_contrast_release(
            m_org_kde_kwin_contrast);
        m_org_kde_kwin_contrast = nullptr;
    }

    void org_kde_kwin_contrast::set_frost(int32_t red, int32_t green, int32_t blue, int32_t alpha)
    {
        org_kde_kwin_contrast_set_frost(
            m_org_kde_kwin_contrast,
            red,
            green,
            blue,
            alpha);
    }

    void org_kde_kwin_contrast::unset_frost()
    {
        org_kde_kwin_contrast_unset_frost(
            m_org_kde_kwin_contrast);
    }
}

QT_WARNING_POP
QT_END_NAMESPACE
